/*
 * irreco - Ir Remote Control
 * Copyright (C) 2008 Joni Kokko (t5kojo01@students.oamk.fi)
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

#include "irreco_theme_manager.h"

/*
 * Contains information of themes
 */
 
/*=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-*/
/* Prototypes                                                                 */
/*=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-*/

/*=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-*/
/* Construction & Destruction                                                 */
/*=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-*/
IrrecoThemeManager *irreco_theme_manager_new(IrrecoData * irreco_data)
{
	IrrecoThemeManager *self;
	IRRECO_ENTER
	
	self = g_slice_new0(IrrecoThemeManager);
	
	self->themes =  irreco_string_table_new(
				(GDestroyNotify)irreco_theme_free, NULL);
	
	/*Get themes*/
	{
		IrrecoDirForeachData bg_styles;

		IRRECO_DEBUG("IRRECO_THEME_DIR = %s\n", IRRECO_THEME_DIR);
		bg_styles.directory = IRRECO_THEME_DIR;

		bg_styles.filesuffix = "";
		bg_styles.user_data_1 = irreco_data;
		bg_styles.user_data_2 = self;
	
		irreco_dir_foreach(&bg_styles,
				   irreco_theme_manager_read_file_foreach);
	}
	
	/* Attempt to add the style to the style array. */
	#if 1
	
	
	IRRECO_STRING_TABLE_FOREACH_DATA(self->themes, void *, theme) {
		IrrecoStringTable* buttons = irreco_theme_get_buttons(theme);
		IRRECO_STRING_TABLE_FOREACH_DATA(buttons, IrrecoThemeButton *,
						 button) {
		IrrecoButtonStyle *style;
		style = irreco_button_style_create(irreco_data,
						   button->name->str, 
						   button->image_up->str,
						   button->image_down->str, 
						   button->allow_text,
						   FALSE);

		if (!irreco_string_table_add(irreco_data->button_style_array,
					     style->name, style)) {
			IRRECO_ERROR("Dublicate style name \"%s\"\n",
				     style->name);
			irreco_button_style_destroy(style);
		}
		
		}
		IRRECO_STRING_TABLE_FOREACH_END
		}
	IRRECO_STRING_TABLE_FOREACH_END

	#endif

	IRRECO_RETURN_PTR(self);
}

void irreco_theme_manager_free(IrrecoThemeManager *self)
{
	IRRECO_ENTER
			
	g_assert(self != NULL);
	
	irreco_string_table_free(self->themes);
	self->themes = NULL;
	
	g_slice_free(IrrecoThemeManager, self);
	self = NULL;

	IRRECO_RETURN
}

/*=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-*/
/* Private Functions                                                          */
/*=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-*/

/*=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-*/
/* Functions                                                                  */
/*=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-*/

void irreco_theme_manager_print(IrrecoThemeManager *self)
{
	IRRECO_ENTER

	#if 1
	irreco_string_table_print(self->themes);
	#endif

	#if 0
	IRRECO_STRING_TABLE_FOREACH_DATA(self->themes, void *, theme)
		IRRECO_PRINTF("Theme: %s \n", theme->name->str);
		irreco_theme_print(theme);
	IRRECO_STRING_TABLE_FOREACH_END
	#endif

	IRRECO_RETURN
}

void irreco_theme_manager_read_file_foreach(IrrecoDirForeachData * dir_data)
{
	IrrecoData *irreco_data = (IrrecoData*) dir_data->user_data_1;
	IrrecoThemeManager *self = (IrrecoThemeManager*) dir_data->user_data_2;
	IrrecoTheme	*theme;
	IRRECO_ENTER
	
	theme = irreco_theme_new(irreco_data, dir_data->filepath);
	
	irreco_string_table_add(self->themes, dir_data->filename, theme);
	
	irreco_theme_print(theme);

	IRRECO_RETURN
}
/*=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-*/
/* Events and Callbacks                                                       */
/*=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-*/

